When is fMRI data independent?

To get independent chunks of data, the experiment itself has to be designed
to allow for this partitioning. Ideally, an experiment is split into
several :term:`chunk`\ s, where each chunk is like a mini-version of the whole
experiment. It contains all conditions, i.e. experimental manipulations of
the independent variables. Another run of the experiment is basically
another version of the mini-experiment, preferrably with a different
randomized trial-order, to minimize this type of signal artefacts in the
data.

At ISMRM 2009, Stephen LaConte presented some guidelines when fMRI
data can be considered *independent*


